d2r=pi/180; r2d=180/pi;
[Apj, Bpj, Cpj, Dpj] = pdes_rcs;                 % Load Pitch RCS Jet Design Model
[Aps, Bps, Cps, Dps] = pdes_surf;                % Load Pitch aero-surf Design Model
[Alj, Blj, Clj, Dlj] = ldes_rcs;                 % Load Lateral RCS Jet Design Model
[Als, Bls, Cls, Dls] = ldes_surf;                % Load Lateral aero-surf Design Model
[Ave, Bve, Cve, Dve] = vehi_sim;                 % Simulation Model 6-dof
load KSmix.mat -ascii;                           % Load Surfaces Mix Logic (4 x 3)
load KJmix.mat -ascii;                           % Load RCS Jets Mix Logic (6 x 3)

alfa0=41.5; V0=24124.0; Thet0=40.3; ge=32.174;   % Additional Vehicle Parameters
calfa=cos(alfa0*d2r); salfa=sin(alfa0*d2r);      % for Body to Stability Transform

% Convert Lateral State Vector from Body to Stability Axes, Outputs=States
Al2= Clj*Alj*inv(Clj); Bl2= Clj*Blj;             % for the Jets
Cl2= Clj*inv(Clj);     Dl2= Dlj;

% Lateral LQR Design Using Only the RCS Jets
[Al5,Bl5,Cl5,Dl5]= linmod('LRdes5x');            % 5-state model {p,r,bet,pint,betint}
R=[1,1]*20; R=diag(R);                           % RCS LQR Weights R=[1,1]*20
Q=[1 1 1 0.5 0.01]*3; Q=diag(Q);                 % RCS LQR Weights Q=[1 1 0.1 0.5 0.005]*3
[KJpr,s,e]=lqr(Al5,Bl5,Q,R);                     % Perform LQR design on Jets

% Convert Lateral State Vector from Body to Stability Axes, Outputs=States
Al2= Cls*Als*inv(Cls); Bl2= Cls*Bls;             % Tranform from Body to Stabil 
Cl2= Cls*inv(Cls);     Dl2= Dls;                 % for the Surfaces

% Lateral LQR Design Using Only the Aero-Surfaces
[Al5,Bl5,Cl5,Dl5]= linmod('LRdes5x');            % 5-state model {p,r,bet,pint,betint}
R=[1,1]*60; R=diag(R);                           % AS LQR Weights R=[1,10]*2
Q=[1 1 1 0.5 0.01]*1; Q=diag(Q);                 % AS LQR Weights Q=[1 1 1 0.04 0.04]*0.4
[KSpr,s,e]=lqr(Al5,Bl5,Q,R);                     % Perform LQR design on Jets

% Pitch LQR Design Using Only the RCS Jets
Apd=Apj; Bpd=Bpj; Cpd=Cpj; Dpd=Dpj;
[Ap4,Bp4,Cp4,Dp4]= linmod('Pdes4x');             % 4-state des model {theta,q,alfa,alf_int}
Ap5= Cp4*Ap4*inv(Cp4); Bp5= Cp4*Bp4;             % Convert to Output=State={theta,q,alfa,alf_int}
Cp5= Cp4*inv(Cp4);     Dp5= Dp4;
R=4; Q=[0.05 0.5  1 1]; Q=diag(Q);               % RCS LQR Weights {theta,q,alfa,alf_int)
[KJq,s,e]=lqr(Ap5,Bp5,Q,R);                      % Perform LQR design on Surf

% Pitch LQR Design Using Only the 4 Aero-Surfaces
Apd=Aps; Bpd=Bps; Cpd=Cps; Dpd=Dps;
[Ap4,Bp4,Cp4,Dp4]= linmod('Pdes4x');             % 4-state des model {theta,q,alfa,alf_int}
Ap5= Cp4*Ap4*inv(Cp4); Bp5= Cp4*Bp4;             % Convert to Output=State={theta,q,alfa,alf_int}
Cp5= Cp4*inv(Cp4);     Dp5= Dp4;
R=2; Q=[0.05 0.5  1 1]; Q=diag(Q);               % AS LQR Weights {theta,q,alfa,alf_int}
[KSq,s,e]=lqr(Ap5,Bp5,Q,R);                      % Perform LQR design on Surf
