% LQR Design & Param Initialization file init.m
d2r=pi/180; r2d=180/pi;
[Aps, Bps, Cps, Dps] = pitch_des;                % Load Pitch aero-surf Design Model
[Als, Bls, Cls, Dls] = later_des;                % Load Lateral aero-surf Design Model
[As,  Bs,  Cs,  Ds]  = vehicle_sim;              % Simulation Model 6-dof
load KSmix.mat -ascii; Kmix=KSmix;               % Load Surfaces Mix Logic (6 x 5)

alfa0=6.0; V0=465.37; Thet0=-16.0; ge=32.174;    % Additional Vehicle Parameters
calfa=cos(alfa0*d2r); salfa=sin(alfa0*d2r);      % for Body to Stability Transform

% Lateral LQR Design Using States: (ps, rs, beta, phi-stab)
% Convert Lateral State Vector from Body to Stability Axes, Outputs=States
[Al4,Bl4,Cl4,Dl4]= linmod('Ldes4x');             % 5-state model {p,r,beta,pint}
Al5= Cl4*Al4*inv(Cl4);  Bl5= Cl4*Bl4;            % Stability axis System
Cl5= Cl4*inv(Cl4);      Dl5= Dl4;
R=[1,1]*1; R=diag(R);                            % LQR Weights R=[1,1]*2
Q=[10 2 1.5 20]; Q=diag(Q);                      % LQR Weights Q=[10 2 0.5 20]
[Kpr,s,e]=lqr(Al5,Bl5,Q,R);                      % Perform LQR design on Jets
save Kpr_T1860.mat Kpr -ascii                    % Lateral State-Feedback Gain

% Pitch LQR Design Using the 6 Aero-Surfaces, States: {theta,q,alfa,dH,dV}
[Ap4,Bp4,Cp4,Dp4]= linmod('Pdes5x');             % Include Kmix in design model
R=[3,1,1]; R=diag(R);                            % LQR Control Weights (Pitch,Nz,Ax)
Q=[0.0001 0.1 0.01 14 4]; Q=diag(Q);             % LQR State Weights {theta,q,alfa,dH,dV}
[Kq,s,e]=lqr(Ap4,Bp4,Q,R);                       % Perform LQR design on Surf
save Kq_T1860.mat Kq -ascii                      % Longitudinal State-Feedback Gain

