% File Init.m for Initialization and Perform Control Design
d2r=pi/180; r2d=180/pi;
[Ave, Bve, Cve, Dve] = vehicle_sim;              % Simulation Model 6-dof
[Aps, Bps, Cps, Dps] = pdes_as;                  % Load Pitch aero-surf Design Model
[Avls,Bvls,Cvls,Dvls]= ldes_as;                  % Load Lateral aero-surf Design Model
[Avlj,Bvlj,Cvlj,Dvlj]= ldes_rcs;                 % Load Lateral RCS Jet Design Model
load KSmix.mat -ascii; KSmix=KSmix;            % Load Surfaces Mix Logic (4 x 3)
load KJmix.mat -ascii; KJmix=KJmix;            % Load RCS Jets Mix Logic (4 x 3)
load KSmix_1550.mat -ascii;
load KSpr_1550.mat -ascii;

alfa0=14.5; V0=2649.4; Thet0=13.3; ge=32.174;    % Additional Parameters for Sim
calfa=cos(alfa0*d2r); salfa=sin(alfa0*d2r);      % for Body to Stability Transform

% Pitch LQR Design Using the 4 Aero-Surfaces, States: {gamm_int,gamma,q,alfa}
[Ap4,Bp4,Cp4,Dp4]= linmod('Pdes4x');             % 4-state des model {gami,gama,q,alfa}
Ap5= Cp4*Ap4*inv(Cp4); Bp5= Cp4*Bp4;             % Convert to Output=State={gami,gama,q,alfa}
Cp5= Cp4*inv(Cp4);     Dp5= Dp4;
R=4; Q=[2 5 2 2]*5; Q=diag(Q);                   % LQR Weights {gami,gama,q,alfa}
[Kq,s,e]=lqr(Ap5,Bp5,Q,R)                        % Perform LQR design on Surf
save Kq.mat Kq -ascii

% Lateral LQR Design Using Only the RCS Jets
Alj= Cvlj*Avlj*inv(Cvlj); Blj= Cvlj*Bvlj;        % Tranform Vector from Body to Stability
Clj= Cvlj*inv(Cvlj);      Dlj= Dvlj;             % for the RCS Jets
[Al5,Bl5,Cl5,Dl5]= linmod('LRdes5x');            % 5-state model {p,r,bet,pint,betint}
R=[1,1]*4; R=diag(R);                            % RCS LQR Weights R=[1,10]*2
Q=[2 0.2 0.2 1 0.01]*1; Q=diag(Q);                 % RCS LQR Weights Q=[1 1 1 0.04 0.04]*0.4
[KJpr,s,e]=lqr(Al5,Bl5,Q,R)                      % Perform LQR design on Jets
save KJpr.mat KJpr -ascii

% Lateral LQR Design Using Only the Aero-Surfaces
Als= Cvls*Avls*inv(Cvls); Bls= Cvls*Bvls;        % Tranform Vector from Body to Stability 
Cls= Cvls*inv(Cvls);      Dls= Dvls;             % for the Surfaces
[Al5,Bl5,Cl5,Dl5]= linmod('LSdes5x');            % 5-state model {p,r,bet,pint,betint}
R=[1,1]*2; R=diag(R);                            % AS LQR Weights R=[1,10]*2
Q=[2 0.2 0.2 1 0.01]*0.8; Q=diag(Q);               % AS LQR Weights Q=[1 1 1 0.04 0.04]*0.4
[KSpr,s,e]=lqr(Al5,Bl5,Q,R)                      % Perform LQR design on Surfaces
save KSpr.mat KSpr -ascii
